@@ -6,19 +6,7 @@ from mtdata.index import Index, Entry
 
 def load_all(index: Index):
 
-    cite="""@inproceedings{post-etal-2012-constructing,
-    title = "Constructing Parallel Corpora for Six {I}ndian Languages via Crowdsourcing",
-    author = "Post, Matt  and
-      Callison-Burch, Chris  and
-      Osborne, Miles",
-    booktitle = "Proceedings of the Seventh Workshop on Statistical Machine Translation",
-    month = jun,
-    year = "2012",
-    address = "Montr{\'e}al, Canada",
-    publisher = "Association for Computational Linguistics",
-    url = "https://www.aclweb.org/anthology/W12-3152",
-    pages = "401--409",
-}"""
+    cite = index.ref_db.get_bibtex(key='post-etal-2012-constructing')
     url = 'https://github.com/joshua-decoder/indian-parallel-corpora/archive/a2cd1a99.tar.gz'
     l2 = 'en'
     langs = ['ml', 'hi', 'ur', 'bn', 'te', 'ta']
