@@ -39,7 +39,6 @@ class Parser:
     def __post_init__(self):
         if not isinstance(self.paths, list):
             self.paths = [self.paths]
-        assert 1 <= len(self.paths) <= 3
         for p in self.paths:
             assert p.exists(), f'{p} not exists'
 
@@ -50,6 +49,9 @@ class Parser:
                 exts = ['txt']  # treat that as plain text
             assert len(set(exts)) == 1, f'Expected a type of exts, but found: {exts}'
             self.ext = exts[0]
+        assert 1 <= len(self.paths)
+        # tsv and tmx just concatenate all of them
+        assert len(self.paths) <= 3 or self.ext == 'tmx' or self.ext == 'tsv'
 
     def read_segs(self):
         readers = []
@@ -73,11 +75,17 @@ class Parser:
                 elif 'sgm' in self.ext:
                     from mtdata.sgm import read_sgm
                     readers.append(read_sgm(p))
+                elif 'wmt21xml' in self.ext:
+                    from mtdata.sgm import read_wmt21_xml
+                    readers.append(read_wmt21_xml(p))
                 else:
                     raise Exception(f'Not supported {self.ext} : {p}')
 
         if len(readers) == 1:
             yield from readers[0]
+        elif self.ext == 'tmx' or self.ext == 'tsv':
+            for reader in readers:
+                yield from reader
         elif len(readers) == 2:
             for seg1, seg2 in zip_longest(*readers):
                 if seg1 is None or seg2 is None:
